@@ -39,13 +39,13 @@ void ParserTest::testSingleAttachment()
     QVERIFY(parser.openFile(QString(QLatin1String(TESTSOURCEDIR) + QLatin1String("one-file.tnef"))) == true);
 
     KTNEFMessage *msg = parser.message();
-    QVERIFY(msg != 0);
+    QVERIFY(msg != nullptr);
 
     QList<KTNEFAttach *> atts = msg->attachmentList();
     QVERIFY(atts.count() == 1);
 
     KTNEFAttach *att = atts.first();
-    QVERIFY(att != 0);
+    QVERIFY(att != nullptr);
     QVERIFY(att->size() == 244);
     QVERIFY(att->name() == QLatin1String("AUTHORS"));
 }
@@ -56,18 +56,18 @@ void ParserTest::testTwoAttachments()
     QVERIFY(parser.openFile(QString(QLatin1String(TESTSOURCEDIR) + QLatin1String("two-files.tnef"))) == true);
 
     KTNEFMessage *msg = parser.message();
-    QVERIFY(msg != 0);
+    QVERIFY(msg != nullptr);
 
     QList<KTNEFAttach *> atts = msg->attachmentList();
     QVERIFY(atts.count() == 2);
 
     KTNEFAttach *att = atts.takeFirst();
-    QVERIFY(att != 0);
+    QVERIFY(att != nullptr);
     QVERIFY(att->size() == 244);
     QVERIFY(att->name() == QLatin1String("AUTHORS"));
 
     att = atts.takeFirst();
-    QVERIFY(att != 0);
+    QVERIFY(att != nullptr);
     QVERIFY(att->size() == 893);
     QVERIFY(att->name() == QLatin1String("README"));
 }
@@ -78,23 +78,23 @@ void ParserTest::testMAPIAttachments()
     QVERIFY(parser.openFile(QString(QLatin1String(TESTSOURCEDIR) + QLatin1String("mapi_attach_data_obj.tnef"))) == true);
 
     KTNEFMessage *msg = parser.message();
-    QVERIFY(msg != 0);
+    QVERIFY(msg != nullptr);
 
     QList<KTNEFAttach *> atts = msg->attachmentList();
     QVERIFY(atts.count() == 3);
 
     KTNEFAttach *att = atts.takeFirst();
-    QVERIFY(att != 0);
+    QVERIFY(att != nullptr);
     QVERIFY(att->size() == 61952);
     QVERIFY(att->name() == QLatin1String("VIA_Nytt_1402.doc"));
 
     att = atts.takeFirst();
-    QVERIFY(att != 0);
+    QVERIFY(att != nullptr);
     QVERIFY(att->size() == 213688);
     QVERIFY(att->name() == QLatin1String("VIA_Nytt_1402.pdf"));
 
     att = atts.takeFirst();
-    QVERIFY(att != 0);
+    QVERIFY(att != nullptr);
     QVERIFY(att->size() == 68920);
     QVERIFY(att->name() == QLatin1String("VIA_Nytt_14021.htm"));
 }
@@ -105,7 +105,7 @@ void ParserTest::testUmlautAttachmentFilenames()
     QVERIFY(parser.openFile(QString(QLatin1String(TESTSOURCEDIR) + QLatin1String("umlaut-filename.tnef"))) == true);
 
     KTNEFMessage *msg = parser.message();
-    QVERIFY(msg != 0);
+    QVERIFY(msg != nullptr);
 
     QList<KTNEFAttach*> atts = msg->attachmentList();
     QVERIFY(atts.count() == 1);
